@@ -32,6 +32,13 @@
 # define VTKIOXDMF3_NO_DEPRECATED
 #endif
 
-
+/* AutoInit implementations.  */
+#if defined(vtkIOXdmf3_INCLUDE)
+# include vtkIOXdmf3_INCLUDE
+#endif
+#if defined(vtkIOXdmf3_AUTOINIT)
+# include "vtkAutoInit.h"
+VTK_AUTOINIT(vtkIOXdmf3)
+#endif
 
 #endif
